# butler

      Welcome to Butler API Documentation and Explorer
      Butler API is built on and conforms to Open API 3.0 spec.
      This enables you to automatically generate language specific clients for
      languages/frameworks listed here: https://openapi-generator.tech/docs/generators/#client-generators
      

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.1
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import butler
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import butler
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import butler
from pprint import pprint
from butler.api import apps_api
from butler.model.app_run_status_dto import AppRunStatusDto
from butler.model.document_extraction_results_dto import DocumentExtractionResultsDto
# Defining the host is optional and defaults to https://app.butlerlabs.ai
# See configuration.py for a list of all supported configuration parameters.
configuration = butler.Configuration(
    host = "https://app.butlerlabs.ai"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): bearer
configuration = butler.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)


# Enter a context with an instance of the API client
with butler.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = apps_api.AppsApi(api_client)
    app_run_id = "appRunId_example" # str | 

    try:
        # Get the status of an extraction job started by the upload_documents endpoint
        api_response = api_instance.get_app_run_status(app_run_id)
        pprint(api_response)
    except butler.ApiException as e:
        print("Exception when calling AppsApi->get_app_run_status: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://app.butlerlabs.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AppsApi* | [**get_app_run_status**](docs/AppsApi.md#get_app_run_status) | **GET** /api/apps/app_runs/{appRunId}/status | Get the status of an extraction job started by the upload_documents endpoint
*AppsApi* | [**get_document_extraction_results**](docs/AppsApi.md#get_document_extraction_results) | **GET** /api/apps/app_runs/{appRunId}/document_extraction | Get extracted results of an extraction job started by the upload_documents endpoint after it completes
*AppsApi* | [**upload_documents**](docs/AppsApi.md#upload_documents) | **POST** /api/apps/{appId}/upload_documents | Upload documents (PDFs, and image formats) to your app to start an extraction job. Returns an appRunId that can be used to check the status of the extraction job, and get its results
*AuthApi* | [**login**](docs/AuthApi.md#login) | **POST** /api/auth | Authenticates and authorizes the user to access the API
*QueuesApi* | [**get_extraction_results**](docs/QueuesApi.md#get_extraction_results) | **GET** /api/queues/{queueId}/extraction_results | Get paginated list of extraction results for documents matching the query params
*QueuesApi* | [**upload_documents_to_queue**](docs/QueuesApi.md#upload_documents_to_queue) | **POST** /api/queues/{queueId}/uploads | Upload documents to the queue specified by &lt;queueId&gt; for processing


## Documentation For Models

 - [AppRunStatus](docs/AppRunStatus.md)
 - [AppRunStatusDto](docs/AppRunStatusDto.md)
 - [DocExConfidence](docs/DocExConfidence.md)
 - [DocumentExtractionResultsDto](docs/DocumentExtractionResultsDto.md)
 - [DocumentStatus](docs/DocumentStatus.md)
 - [ExtraResultsDto](docs/ExtraResultsDto.md)
 - [ExtractedFieldDto](docs/ExtractedFieldDto.md)
 - [ExtractedTableCellDto](docs/ExtractedTableCellDto.md)
 - [ExtractedTableDto](docs/ExtractedTableDto.md)
 - [ExtractedTableRowDto](docs/ExtractedTableRowDto.md)
 - [ExtractionRangeDto](docs/ExtractionRangeDto.md)
 - [ExtractionResultsDto](docs/ExtractionResultsDto.md)
 - [ExtractionResultsSortBy](docs/ExtractionResultsSortBy.md)
 - [LoginBodyDto](docs/LoginBodyDto.md)
 - [PaginatedExtractionResultsDto](docs/PaginatedExtractionResultsDto.md)
 - [SortOrder](docs/SortOrder.md)
 - [UploadDocumentResponseDto](docs/UploadDocumentResponseDto.md)
 - [UploadDocumentsUploadResponseDto](docs/UploadDocumentsUploadResponseDto.md)


## Documentation For Authorization


## bearer

- **Type**: Bearer authentication (JWT)


## Author




## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in butler.apis and butler.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from butler.api.default_api import DefaultApi`
- `from butler.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import butler
from butler.apis import *
from butler.models import *
```

